import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { HttpModule } from '@angular/http';
import { RouterModule } from '@angular/router';

//Modules
import { KiewitAutoCompleteModule } from '../lib/kiewit-autocomplete';
import { KiewitButtonModule } from '../lib/kiewit-button';
import { KiewitCardModule } from '../lib/kiewit-card';
import { KiewitConfirmationModule } from '../lib/kiewit-confirmation';
import { KiewitGridModule } from '../lib/kiewit-grid';
import { KiewitHeaderModule } from '../lib/kiewit-header';
import { KiewitDropdownModule } from '../lib/kiewit-dropdown';
import { KiewitTabStripModule } from '../lib/kiewit-tabstrip';
import { KiewitNumericTextboxModule } from '../lib/kiewit-numerictextbox';
import { KiewitFooterModule } from '../lib/kiewit-footer';
import { KiewitMenuModule } from '../lib/kiewit-menu/kiewit-menu.module';
import { KiewitColumnchooserModule } from '../lib/kiewit-columnchooser/kiewit-columnchooser.module';
import { KiewitToastmessageModule } from '../lib/kiewit-toastmessage/kiewit-toastmessage.module';
import { KiewitLoaderModule } from '../lib/kiewit-loader'; 
import { DropDownsModule } from '@progress/kendo-angular-dropdowns';

import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { NoopAnimationsModule } from '@angular/platform-browser/animations';

//Components
import { AppComponent } from './app.component';
import { DashboardComponent } from './components/dashboard/dashboard.component';
import { ManageApplicationComponent } from './components/manage-application/manage-application.component';
import { ManageRolesComponent } from './components/manage-roles/manage-roles.component';
import { UserRolesComponent } from './components/user-roles/user-roles.component';

//Services
import { KiewitLoggingService } from './../lib/kiewit-logging/kiewit-logging.service';
import { KiewitAuthenticationService } from './../lib/kiewit-authentication/kiewit-authentication.service';
import { Adal4Service, Adal4HTTPService } from 'adal-angular4';
import { DefaultComponent } from './components/default/default.component';
import { HttpService } from '../Common/http.service';

@NgModule({
    declarations: [
        AppComponent,
        DashboardComponent,
        UserRolesComponent,
        ManageApplicationComponent,
        ManageRolesComponent,
        DefaultComponent
    ],
    imports: [
        BrowserModule,
        FormsModule,
        NoopAnimationsModule,
        HttpModule,
        KiewitButtonModule,
        KiewitCardModule,
        KiewitGridModule,
        KiewitHeaderModule,
        KiewitDropdownModule,
        KiewitAutoCompleteModule,
        KiewitFooterModule,
        KiewitMenuModule,
        KiewitColumnchooserModule,
        KiewitConfirmationModule,
        KiewitColumnchooserModule,
        KiewitToastmessageModule,
        KiewitTabStripModule,
        KiewitNumericTextboxModule,
        KiewitLoaderModule,
        BrowserAnimationsModule,
        DropDownsModule,
        RouterModule.forRoot(
            [
                {
                    path: '',
                    component: DashboardComponent
                },
                {
                    path: 'userroles',
                    component: UserRolesComponent,
                    data: { title: 'User roles' }
                },
                {
                    path: 'manageapplication',
                    component: ManageApplicationComponent
                },
                {
                    path: 'manageroles',
                    component: ManageRolesComponent
                }

                //,
                //{ path: '**', component: PageNotFoundComponent }
            ]//,
            //{ enableTracing: true }
        )
    ],
    providers: [
        KiewitLoggingService,
        KiewitAuthenticationService,
        Adal4Service,
        HttpService,
        {
            provide: Adal4HTTPService,
            useFactory: Adal4HTTPService.factory,
            deps: [HttpModule, Adal4Service]
        }
    ],
    bootstrap: [AppComponent]
})
export class AppModule { }
