import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { Observable } from 'rxjs/Rx';
import { ManageApplicationService } from '../../components/manage-application/manage-application.service';
import { ManageRolesService } from '../manage-roles/manage-roles.service';
import { FormsModule } from '@angular/forms';
import { GridDataResult, PageChangeEvent } from '@progress/kendo-angular-grid';
import { InformationType } from '../../../lib/kiewit-toastmessage';

@Component({
  selector: 'app-manage-application',
  templateUrl: './manage-application.component.html',
  styleUrls: ['./manage-application.component.scss'],
  providers: [ManageApplicationService, ManageRolesService]
})

export class ManageApplicationComponent implements OnInit {

  public gridData = [];
  public txtapplicationName: string;
  public applicationId: number;
  public selectedAppId: any;
  public appsData: Observable<any>;
  public isChecked = true;
  private pageSize = 100;
  private items: any[];
  private updatedItems: any[] = [];
  private gridView: GridDataResult;
  public insertedApplicationId: number;
  public insertedApplicationName: string;
  public insertedRoleSecAdminId: number;
  public insertedRoleAdminId: number;
  public ddlStatus = 'false';
  public appName: string;
  private isDataAdded = true;
  public selectedStatusValue: any;
  public providerItems: any;
  public defaultItemStatus: { STATUS_NAME: string, STATUS_ID: number } = { STATUS_NAME: 'Select Status', STATUS_ID: null };
  toastMessageConfig = {
    showMessage: false,
    informationMessage: '',
    informationType: 1,
    timeOut: 3000
  };
  constructor(private route: ActivatedRoute, private manageApplicationService: ManageApplicationService, private manageRolesService: ManageRolesService, private router: Router) {
    this.applicationId = this.route.snapshot.queryParams['appId'];
    this.ddlStatus = this.route.snapshot.queryParams['ddlStatus'];
    this.appName = this.route.snapshot.queryParams['userAppName'];
  }

  ngOnInit() {
    this.getApplicationData();
  }

  public statusItems: Array<{ STATUS_NAME: string, STATUS_ID: number }> = [
    { STATUS_NAME: "Active", STATUS_ID: 1 },
    { STATUS_NAME: "InActive", STATUS_ID: 2 }
  ];

  private addGridData() {
    if (this.txtapplicationName && this.selectedStatusValue) {
      const gridData = { AppId: 0, UserName: '', Description: '', guid: null, IsActive: null, Name: null, ProviderId: 1 };
      gridData.Name = this.txtapplicationName;
      gridData.IsActive = this.selectedStatusValue.STATUS_NAME == 'Active' ? true : false;
      this.updatedItems.push(gridData);
      this.items.push(gridData);
      this.loadItems();
      this.txtapplicationName = '';
      this.selectedStatusValue = this.defaultItemStatus.STATUS_ID;
      this.isDataAdded = false;
    }
  }

  private saveChanges() {
    if (this.updatedItems.length > 0) {
      let postData = JSON.stringify({ "applicationData": this.updatedItems });
      this.manageApplicationService.saveApplication(postData).subscribe(data => {
        this.getApplicationData();
      });
      this.toastMessageConfig.showMessage = true;
      this.toastMessageConfig.informationMessage = 'Application Created Successfully';
      this.toastMessageConfig.informationType = InformationType.Success;
      this.toastMessageConfig.timeOut = 2000;
      this.updatedItems = [];
      this.isDataAdded = true;
    }
  }

  private cancelChanges() {
    this.getApplicationData();
    this.selectedStatusValue = this.defaultItemStatus.STATUS_ID;
    this.updatedItems = [];
    this.isDataAdded = true;
  }

  //Navigating to user Roles Page --TODO : Need to change later
  private userRolesManage() {
    if (this.appName == 'KCS') {
      this.router.navigate(['/userroles'], {
        queryParams: {
          appId: 2,
          userName: 'KiewitUser4@kiewit.com',
          appName: 'KCS'
        }, skipLocationChange: true
      });
    }
    else {
      this.router.navigate(['/userroles'], {
        queryParams: {
          appId: 1,
          userName: 'KiewitUser@kiewit.com',
          appName: 'BPT'
        }, skipLocationChange: true
      });
    }
  }

  confirmationConfig = {
    isOpened: false,
    title: '',
    yesCaption: 'Yes',
    noCaption: 'No'
  };

  private deleteRow(AppId: any, RoleId: any) {
    this.selectedAppId = AppId;
    this.confirmationConfig.title = 'Are you sure want to delete ?';
    this.confirmationConfig.isOpened = true;
  }

  confirmationYesClicked() {

    this.manageRolesService.deleteApplicationRoles(Number(this.selectedAppId)).subscribe(data => {
      this.manageApplicationService.deleteApplication(Number(this.selectedAppId)).subscribe(data => {
        this.manageApplicationService.getApplication().subscribe(data => {
          if (data.length > 0) {
            this.gridData = data;
            this.items = data;
            this.items.unshift('test');
            this.loadItems();
            this.appsData = data;
            this.selectedAppId = null;
          }
        });
        this.toastMessageConfig.showMessage = true;
        this.toastMessageConfig.informationMessage = 'Application Deleted Successfully';
        this.toastMessageConfig.informationType = InformationType.Success;
      });
    });
  }

  private getApplicationData() {
    this.manageApplicationService.getApplication().subscribe(data => {
      if (data.length > 0) {
        this.gridData = data;
        this.items = data;
        if (this.appName == 'KCS') {
          this.items.unshift('test');
        }
        this.loadItems();
      }
    });
  }

  //protected pageChange(event: PageChangeEvent): void {
  //  this.skip = event.skip;
  //  this.loadItems();
  //}

  private loadItems(): void {
    this.gridView = {
      data: this.items,
      total: this.items.length
    };

  }

 

}
