import { Component, OnInit } from '@angular/core';
import { Observable } from 'rxjs/Rx';
import { ManageRolesService } from '../../components/manage-roles/manage-roles.service';
import { FormsModule, FormBuilder, Validators, FormGroup } from '@angular/forms';
import { IKiewitDropdown } from '../../../index';
import { ActivatedRoute, Router } from '@angular/router';
import { GridDataResult, PageChangeEvent } from '@progress/kendo-angular-grid';
import { InformationType } from '../../../lib/kiewit-toastmessage';

@Component({
  selector: 'app-manage-roles',
  templateUrl: './manage-roles.component.html',
  styleUrls: ['./manage-roles.component.scss'],
  providers: [ManageRolesService]
})

export class ManageRolesComponent implements OnInit {

  public roleData: Observable<any>;
  public gridData = [];
  public statusData: any;
  public applicationId: number;
  public appsData: Observable<any>;
  public rolesData: Observable<any>;
  public roleName: string;
  public isActive = true;
  public insertedRoleId: number;
  public selectedAppValue: any;
  public selectedAppRole: any;
  public selectedStatusValue: any;
  public selectedRole: any;
  private pageSize = 100;
  private items: any[];
  private updatedItems: any[] = [];
  private gridView: GridDataResult;
  private ddlAppStatus = false;
  private appName: string;
  private isDataAdded = true;
  public defaultItemApp: any = { Name: 'Select Application', AppId: null };
  public defaultItemStatus: any = { STATUS_NAME: 'Select Status', STATUS_ID: null };
  confirmationConfig = {
    isOpened: false,
    title: 'Are you sure want to delete?',
    yesCaption: 'Yes',
    noCaption: 'No'
  };

  constructor(private route: ActivatedRoute, private router: Router, private manageRolesService: ManageRolesService, private formBuilder: FormBuilder) {
    this.applicationId = this.route.snapshot.queryParams['appId'];
    this.ddlAppStatus = JSON.parse(this.route.snapshot.queryParams['ddlStatus']);
    this.appName = this.route.snapshot.queryParams['userAppName'];
  }

  toastMessageConfig = {
    showMessage: false,
    informationMessage: '',
    informationType: InformationType.Success,
    timeOut: 3000
  };

  ngOnInit() {

    this.selectedAppValue = this.appName == 'KCS' ? this.defaultItemApp.AppId : Number(this.applicationId);
    this.selectedAppRole = Number(this.applicationId);
    this.selectedStatusValue = this.defaultItemStatus.Id;

    this.manageRolesService.getApplication().subscribe(data => {
      if (data.length > 0) {
        this.appsData = data;
      }
    });
    if (this.appName === 'KCS') {
      this.getApplicationRoles(this.applicationId, this.appName);
    }
    else {
      this.getApplicationRolesById(this.applicationId);
    }
  }

  private getApplicationRoles(appId: number, appName: string) {
    this.manageRolesService.getApplicationRoles(appId, appName).subscribe(data => {
      if (data.length > 0) {
        this.gridData = data;
        this.items = data;
        this.items.unshift('test');
        this.loadItems();
      }
    });
  }

  public statusItems: Array<{ STATUS_NAME: string, STATUS_ID: number }> = [
    { STATUS_NAME: "Active", STATUS_ID: 1 },
    { STATUS_NAME: "InActive", STATUS_ID: 2 }
  ];

  private getApplicationRolesById(appId: number) {
    this.manageRolesService.getApplicationRolesById(appId).subscribe(data => {
      if (data.length > 0) {
        this.gridData = data;
        this.items = data;
        this.items.unshift('test');
        this.loadItems();
      }
    });
  }
  //Temporarily addded - TODO : Have to remove later
  private userRolesManage() {
    if (this.appName == 'KCS') {
      this.router.navigate(['/userroles'], {
        queryParams: {
          appId: 2,
          userName: 'KiewitUser4@kiewit.com',
          appName: 'KCS'
        }, skipLocationChange: true
      });
    }
    else {
      this.router.navigate(['/userroles'], {
        queryParams: {
          appId: 1,
          userName: 'KiewitUser4@kiewit.com',
          appName: 'BPT'
        }, skipLocationChange: true
      });
    }
  }

  private addGridData() {
    if (this.roleName && this.selectedStatusValue && this.selectedAppValue) {
      this.isDataAdded = false;
      if (this.appName == "KCS") {
        this.getApplicationsbyId(this.selectedAppValue.AppId);
        this.selectedAppValue = this.defaultItemApp.AppId;
      }
      else {
        this.getApplicationsbyId(this.selectedAppValue);
      }
    }
  }
  public getApplicationsbyId(selectedAppId: number) {
    const gridData = { AppId: 0, Application: null, RoleId: 0, Role: null, Status: null };
    this.manageRolesService.getApplicationbyId(selectedAppId).subscribe(data => {
      gridData.Application = data[0].Name;
      gridData.AppId = data[0].AppId;
      gridData.Role = this.roleName;
      gridData.Status = this.selectedStatusValue.STATUS_NAME;
      this.updatedItems.push(gridData);
      this.items.push(gridData);
      this.loadItems();
      this.roleName = '';
      this.selectedStatusValue = this.defaultItemStatus.STATUS_ID;
    });
  }

  private saveChanges() {
    if (this.updatedItems.length > 0) {
      for (let i = 0; i < this.updatedItems.length; i++) {
        const roleName = this.updatedItems[i].Role;
        const appId = this.updatedItems[i].AppId;
        const status = this.updatedItems[i].Status == 'Active' ? true : false;
        this.manageRolesService.saveRoles(roleName, status).subscribe(data => {
          if (data) {
            this.insertedRoleId = data.RoleId;
            this.manageRolesService.saveApplicationRoles(this.insertedRoleId, appId, status).subscribe(data => {
              if (this.appName == 'KCS') {
                this.getApplicationRoles(this.applicationId, this.appName);
                this.selectedAppValue = this.defaultItemApp.AppId;
              } else {
                this.getApplicationRolesById(this.applicationId);
              }
              this.toastMessageConfig.showMessage = true;
              this.toastMessageConfig.informationMessage = 'Role Created Successfully';
              this.roleName = null;
            });
          }
        });
      }
      this.selectedStatusValue = this.defaultItemStatus.STATUS_ID;
      this.roleName = '';
      this.updatedItems = [];
      this.isDataAdded = true;
    }
  }

  private cancelChanges() {
    if (this.appName == 'KCS') {
      this.getApplicationRoles(this.applicationId, this.appName);
      this.selectedAppValue = this.defaultItemApp.AppId;
    } else {
      this.getApplicationRolesById(this.applicationId);
    }
    this.roleName = '';
    this.selectedStatusValue = this.defaultItemStatus.STATUS_ID;
    this.updatedItems = [];
    this.isDataAdded = true;
  }

  private deleteRow(AppId: any, RoleId: any) {
    this.selectedRole = RoleId;
    this.selectedAppValue = AppId;
    this.confirmationConfig.title = 'Are you sure want to delete ?';
    this.confirmationConfig.isOpened = true;
  }

  confirmationYesClicked() {
    if (this.selectedRole != undefined && this.selectedAppValue != undefined) {
      this.manageRolesService.getUserRolesByRoleId(this.selectedRole).subscribe(data => {
        if (data.length <= 0) {
          //deleting applicationRole
          this.manageRolesService.deleteApplicationRole(this.selectedAppValue, this.selectedRole).subscribe(data => {
            this.manageRolesService.deleteRole(this.selectedRole).subscribe(data => { });
            this.toastMessageConfig.showMessage = true;
            this.toastMessageConfig.informationMessage = 'Selected role has been deleted';
            this.toastMessageConfig.informationType = InformationType.Failure;
            if (this.appName == 'KCS') {
              this.getApplicationRoles(this.applicationId, this.appName);
            } else {
              this.getApplicationRolesById(this.selectedAppValue);
            }
          });
        }
        else {
          this.toastMessageConfig.showMessage = true;
          this.toastMessageConfig.informationMessage = 'User is Assigned to this Role, please Un-assign and try again';
          this.toastMessageConfig.timeOut = 3000;
        }
      });
    }
  }

  //protected pageChange(event: PageChangeEvent): void {
  //  this.skip = event.skip;
  //  this.loadItems();
  //}

  private loadItems(): void {
    this.gridView = {
      data: this.items,
      total: this.items.length
    };
  }
}
