import { Injectable } from '@angular/core';
import { URLSearchParams } from '@angular/http';
import { HttpService } from '../../../Common/http.service';
import { FormsModule } from '@angular/forms';
import { environment } from '../../../environments/environment';

@Injectable()
export class ManageRolesService {

  constructor(private httpService: HttpService) { }

  getApplication() {
    const uri = environment.kcsServiceUrl + 'Applications';
    const params = new URLSearchParams();
    return this.httpService.httpGetService(uri, params);
  }
  getApplicationbyId(appId: number) {
    const uri = environment.kcsServiceUrl + 'Applications?$filter=AppId eq (' + appId + ')';
    const params = new URLSearchParams();
    return this.httpService.httpGetService(uri, params);
  }
  getRoles() {
    const uri = environment.kcsServiceUrl + 'Roles';
    const params = new URLSearchParams();
    return this.httpService.httpGetService(uri, params);
  }

  getUserRolesByRoleId(roleId: number)
  {
    const uri = environment.kcsServiceUrl + 'UserRoles?$filter=RoleId eq (' + roleId + ')';
    const params = new URLSearchParams();
    return this.httpService.httpGetService(uri, params);
  }
  getApplicationRolesById(appId: number) {

    const uri = environment.kcsServiceUrl + 'GetApplicationRolesById(applicationId=' + appId + ')';
    const params = new URLSearchParams();
    return this.httpService.httpGetService(uri, params);
  }
  getApplicationRoles(appId: number, appname: string) {

    const uri = environment.kcsServiceUrl + 'GetApplicationRoles(applicationId=' + appId + ',appName=\'' + appname + '\')';
    const params = new URLSearchParams();
    return this.httpService.httpGetService(uri, params);
  }


  saveRoles(roleName: string, isActive: boolean) {
    const role = {
      Name: roleName,
      Description: '',
      CreatedBy: 'Admin',
      IsActive: isActive
    };
    const uri = environment.kcsServiceUrl + 'Roles';
    return this.httpService.httpPostService(uri, role);
  }

  saveApplicationRoles(roleId: number, appId: number, isActive: boolean) {
    const roleApplication = {
      RoleId: roleId,
      ApplicationId: appId,
      IsActive: isActive
    };
    const uri = environment.kcsServiceUrl + 'ApplicationRoles';
    return this.httpService.httpPostService(uri, roleApplication);
  }

  getRolebyApplication(roleName: string, appId: string) {
    const uri = environment.kcsServiceUrl + 'ApplicationRoles?$expand=Role&$filter=Role/Name eq ' + roleName + '  and ApplicationId eq ' + appId;
    const params = new URLSearchParams();
    return this.httpService.httpGetService(uri, params);
  }

  deleteRole(roleId: string)
  {
    const uri = environment.kcsServiceUrl + 'Roles' + '(' + roleId + ')';
    const params = new URLSearchParams();
    return this.httpService.httpDeleteService(uri, params);
  }

  deleteApplicationRoles(appId: number) {
    const uri = environment.kcsServiceUrl + 'DeleteApplicationRoles(applicationId=' + appId + ')';
    const params = new URLSearchParams();
    return this.httpService.httpDeleteService(uri, params);
  }
  deleteApplicationRole(appId: number, roleId: number) {
    const uri = environment.kcsServiceUrl + 'DeleteApplicationRole(applicationId=' + appId + ',roleId=' + roleId + ')';
    const params = new URLSearchParams();
    return this.httpService.httpDeleteService(uri, params);
  }
}

