﻿function initializeCurrencyTextbox(selector) {

  $(selector).unbind();

  $(selector).keydown(function (e) {

    var ctl = $(this)[0];
    var startPos = ctl.selectionStart;

    if (e.keyCode == 190 || e.keyCode == 110) return false;

    if (e.keyCode == 190 || e.keyCode == 110) {
      var inputValue = $(this).val();
      if (inputValue.length > 0 && inputValue.indexOf(".") == -1) {
        return true;
      }
      return false;
    }

    if (e.shiftKey && e.keyCode == 189) return false;

    if (e.keyCode == 189) {
      var inputValue = $(this).val();
      if (inputValue.indexOf('-') == -1 && startPos == 0) {
        return true;
      }
      return false;
    }

    // Allow: backspace, delete, tab, escape, enter and .
    if ($.inArray(e.keyCode, [46, 8, 9, 27, 13, 110, 189, 190]) !== -1 ||
      // Allow: Ctrl/cmd+A
      (e.keyCode == 65 && (e.ctrlKey === true || e.metaKey === true)) ||
      // Allow: Ctrl/cmd+C
      (e.keyCode == 67 && (e.ctrlKey === true || e.metaKey === true)) ||
      // Allow: Ctrl/cmd+X
      (e.keyCode == 88 && (e.ctrlKey === true || e.metaKey === true)) ||
      // Allow: home, end, left, right
      (e.keyCode >= 35 && e.keyCode <= 39)) {
      // let it happen, don't do anything
      return;
    }

    if (e.ctrlKey)
      return true;

    // Ensure that it is a number and stop the keypress
    if ((e.shiftKey || (e.keyCode < 48 || e.keyCode > 57)) && (e.keyCode < 96 || e.keyCode > 105)) {
      e.preventDefault();
    }
  });


  $(selector).blur(function () {
    if ($(this).val() == "" || $(this).val() == "-") return "";

    var decimalPlaces = $(this).attr("decimal-places");
    if (!decimalPlaces)
      decimalPlaces = 2;

    var currentValue = parseFloat($(this).val()).toFixed(decimalPlaces);
    $(this).val(numberWithCommas(currentValue));
  });

  function numberWithCommas(currentValue) {
    var isNegative = false;

    if (currentValue < 0) {
      currentValue = -1 * currentValue;
      isNegative = true;
    }

    var parts = currentValue.toString().split(".");
    parts[0] = parts[0].replace(/\B(?=(\d{3})+(?!\d))/g, ",");

    if (isNegative)
      return "($" + parts.join(".") + ")";

    return "$" + parts.join(".");
  }

  $(selector).focus(function () {
    var currentValue = $(this).val();
    if (currentValue == "" || currentValue == "-") return "";

    if (currentValue.indexOf('(') == 0)
      currentValue = "-" + currentValue.toString();

    $(this).val(escapeRegExp(currentValue));
  });

  function escapeRegExp(str) {
    return str.replace(/[,*+?^${}()|[\]\\]/g, ""); // $& means the whole matched string
  }


  $(selector).bind('paste', function (e) {
    setTimeout(function () {
      if (isNaN(e.target.value))
        e.target.value = "";
    });
  });
}

function initializePercentageTextbox(selector) {

  $(selector).unbind();

  $(selector).keydown(function (e) {

    var ctl = $(this)[0];
    var startPos = ctl.selectionStart;

    if (e.shiftKey && e.keyCode == 190) return false;

    if (e.keyCode == 190 || e.keyCode == 110) {
      var inputValue = $(this).val()
      if (inputValue.length > 0 && inputValue.indexOf(".") == -1) {
        return true;
      }
      return false;
    }

    if (e.keyCode == 189) return false;

    if (e.keyCode == 189) {
      var inputValue = $(this).val()
      if (inputValue.indexOf('-') == -1 && startPos == 0) {
        return true;
      }
      return false;
    }

    // Allow: backspace, delete, tab, escape, enter and .
    if ($.inArray(e.keyCode, [46, 8, 9, 27, 13, 110, 189, 190]) !== -1 ||
      // Allow: Ctrl/cmd+A
      (e.keyCode == 65 && (e.ctrlKey === true || e.metaKey === true)) ||
      // Allow: Ctrl/cmd+C
      (e.keyCode == 67 && (e.ctrlKey === true || e.metaKey === true)) ||
      // Allow: Ctrl/cmd+X
      (e.keyCode == 88 && (e.ctrlKey === true || e.metaKey === true)) ||
      // Allow: home, end, left, right
      (e.keyCode >= 35 && e.keyCode <= 39)) {
      // let it happen, don't do anything
      return;
    }

    if (e.ctrlKey)
      return true;

    // Ensure that it is a number and stop the keypress
    if ((e.shiftKey || (e.keyCode < 48 || e.keyCode > 57)) && (e.keyCode < 96 || e.keyCode > 105)) {
      e.preventDefault();
    }
  });


  $(selector).blur(function () {
    if ($(this).val() == "" || $(this).val() == "-") return "";

    var decimalPlaces = $(this).attr("decimal-places");
    if (!decimalPlaces)
      decimalPlaces = 2;

    var currentValue = parseFloat($(this).val()).toFixed(decimalPlaces);

    $(this).val(numberWithPercentage(currentValue));
  });

  $(selector).keyup(function () {
    if ($(this).val() == "" || $(this).val() == "-") return "";

    var currentValue = $(this).val();

    if (parseFloat(currentValue) > 100)
      $(this).val(100);

    if (parseFloat(currentValue) < 0)
      $(this).val(0);
  });

  function numberWithPercentage(currentValue) {

    var parts = currentValue.toString().split(".");
    parts[0] = parts[0].replace(/\B(?=(\d{3})+(?!\d))/g, ",");

    return parts.join(".") + " %";
  }

  $(selector).focus(function () {
    var currentValue = $(this).val();
    if (currentValue == "" || currentValue == "-") return "";
    $(this).val(escapeRegExp(currentValue));
  });

  function escapeRegExp(str) {
    return str.replace(/[ %,*+?^${}()|[\]\\]/g, ""); // $& means the whole matched string
  }


  $(selector).bind('paste', function (e) {
    setTimeout(function () {
      if (isNaN(e.target.value))
        e.target.value = "";
    });
  });
}


Array.prototype.moveUp = function (index, by) {
  var newPos = index - (by || 1);

  var item = this[index];

  if (index === -1)
    return false;

  if (newPos < 0)
    newPos = 0;

  this.splice(index, 1);
  this.splice(newPos, 0, item);
};

Array.prototype.moveDown = function (index, by) {
  var newPos = index + (by || 1);
  var item = this[index];

  if (index === -1)
    return false

  if (newPos >= this.length)
    newPos = this.length;

  this.splice(index, 1);
  this.splice(newPos, 0, item);
};