﻿import { Component, Input, OnChanges, Output, EventEmitter, ViewChild, ElementRef } from '@angular/core';
import { KiewitCard } from './kiewit-card';

@Component({
    selector: 'kiewit-card',
    templateUrl: './kiewit-card.component.html',
    styleUrls: ['./kiewit-card.component.scss']
})
export class KiewitCardComponent implements OnChanges {

    @Input() cardList: KiewitCard[];
    @Output() kcsAddCardClick: EventEmitter<any> = new EventEmitter();
    @Output() kcsCardClick: EventEmitter<any> = new EventEmitter();
    @Output() kcsElipsisOptionClick: EventEmitter<any> = new EventEmitter();
    @Output() kcsCardHeaderMenuIconClick: EventEmitter<any> = new EventEmitter();
    @ViewChild('cardTitle') cardTitle:  ElementRef;

    private start: any[];
    private hoveredDivId: number;
    private elicpseClickedCardId: number;
    private hoveredDivStyles = { 'background-color': '#F2F2F2' };
    private displayHeaderOptions = { 'display': 'inline-block' };
    private displayElipsisOption = { 'visibility': 'visible' };
    private isDisplayElipsisOption = false;
    private isShowOptionsLeft = false;

    //for testing the input data
    ngOnChanges(): void {
        this.start = this.cardList;
    }
    showDivWithHoverStyles(id: number, cardHoverStateBgColor: string): void {
        this.hoveredDivId = id;
        if (cardHoverStateBgColor) {
            this.hoveredDivStyles = { 'background-color': '' + cardHoverStateBgColor + '' };
        } else {
            this.hoveredDivStyles = { 'background-color': '#F2F2F2' };
        }
    }
    showAllDivsWithDefaultStyles(): void {
        this.hoveredDivId = null;
    }
    kiewitCardElipsisClick(event: any, cardidex: number): void {
        const screenWidth = window.screen.availWidth;
        if (screenWidth == 1366 && cardidex == 3) {
            this.isShowOptionsLeft = true;
        }
        else if (screenWidth == 1600 && cardidex == 5) {
            this.isShowOptionsLeft = true;
        }else {
            this.isShowOptionsLeft = false;
        }
        this.elicpseClickedCardId = cardidex;
        this.isDisplayElipsisOption = !this.isDisplayElipsisOption;
        event.stopPropagation();
    }


    innerCardMouseEnter() {
        this.isDisplayElipsisOption = false;
    }
    getOptionsPopUpClass(): string {
        if (this.isShowOptionsLeft) {
            return 'kiewit-card-options-text-left';
        } else {
            return 'kiewit-card-options-text';
        }
    }
    getOptionsPopUpTrianngleClass(): string {
        if (this.isShowOptionsLeft) {
            return 'spanoftriangle-left';
        } else {
            return 'spanoftriangle';
        }
    }

    //events to export
    kiewitAddCardClicked() {
        this.kcsAddCardClick.emit();
    }
    kiewitCardClicked(card: any) {
        this.kcsCardClick.emit(card);
    }
    kiewitElipsisOptionClicked(card, menu) {
        this.kcsElipsisOptionClick.emit({ card: card, menu: menu });
    }
    kiewitHeaderMenuIconClicked(card, menu) {
        this.kcsCardHeaderMenuIconClick.emit({ card: card, menu: menu });
        event.stopPropagation();
    }
}
