﻿import { Component, OnInit, Input, Output, ViewChild, EventEmitter, ElementRef } from '@angular/core';

@Component({
    selector: 'kiewit-columnchooser',
    templateUrl: './kiewit-columnchooser.component.html',
    styleUrls: ['./kiewit-columnchooser.component.scss']
})
export class KiewitColumnChooserComponent implements OnInit {
    @Input() config: any = {
        availableColumns: [],
        selectedColumns: [],
        isOpened: false,
    };
    @Output() kcsColumnChooserClick: EventEmitter<any> = new EventEmitter();
    @Output() kcsColumnChooserClose: EventEmitter<any> = new EventEmitter();
    @Output() kcsColumnChooserSaveClick = new EventEmitter();

    @ViewChild('lstavailable') availablelist: ElementRef;
    @ViewChild('lstselected') selectedlist: ElementRef;

    private isDataChanged = true;
    private isRightIconsDisabled = false;
    isUpDownIconDisabled = false;
    isLeftIconsDisabled = false;



    constructor() {

    }

    ngOnInit() {
    }

    saveColumnChooser() {
        const columnChooserData = { 'availableColumns': this.config.availableColumns, 'selectedColumns': this.config.selectedColumns, 'isDataChanged': this.isDataChanged};
        this.kcsColumnChooserSaveClick.emit(columnChooserData);
        this.isDataChanged = true;
    }

    columnChooserClick() {
        this.kcsColumnChooserClick.emit();
        this.config.isOpened = true;
    }
    private closeColumnChooser(isMainClose: boolean) {
        if (!isMainClose)
            this.resetIconsToDefault();
        this.isDataChanged = true;
        this.config.isOpened = false;
        this.kcsColumnChooserClose.emit();
    }

    onSelectionChanged(e: any) {

        if (e.target.className === 'selectedList') {
            const selected = this.getSelectedOptions('SELECTED');

            if (selected && selected.length == 1)
                this.isUpDownIconDisabled = true;
            else
                this.isUpDownIconDisabled = false;

            this.isLeftIconsDisabled = true;
            this.isRightIconsDisabled = false;
        }
        else {
            this.isUpDownIconDisabled = false;
            this.isLeftIconsDisabled = false;
            this.isRightIconsDisabled = true;
        }
    }

    onMoveRight(e: any) {
        if (e.currentTarget.className.indexOf('columnchooser-directional-icons-disabled') != -1) return false;

        const selected = this.getSelectedOptions('AVAILABLE');

        this.isDataChanged = false;
        for (let currentindex = 0; currentindex < selected.length; currentindex++) {
            this.config.selectedColumns.push(this.config.availableColumns[selected[currentindex].index]);
        }

        for (let currentindex = 0; currentindex < selected.length; currentindex++) {
            for (let index = 0; index < this.config.availableColumns.length; index++) {
                if (this.config.availableColumns[index].title === selected[currentindex].text) {
                    this.config.availableColumns.splice(index, 1);
                    break;
                }
            }
        }

        this.resetIconsToDefault();
    }

    onMoveLeft(e: any) {

        if (e.currentTarget.className.indexOf('columnchooser-directional-icons-disabled') != -1) return false;

        const selected = this.getSelectedOptions('SELECTED');

        this.isDataChanged = false;
        for (let currentindex = 0; currentindex < selected.length; currentindex++) {
            this.config.availableColumns.push(this.config.selectedColumns[selected[currentindex].index]);
        }
        for (let currentindex = 0; currentindex < selected.length; currentindex++) {
            for (let index = 0; index < this.config.selectedColumns.length; index++) {
                if (this.config.selectedColumns[index].title === selected[currentindex].text) {
                    this.config.selectedColumns.splice(index, 1);
                    break;
                }
            }
        }

        this.resetIconsToDefault();
    }
    onMoveUp(e: any) {
        if (e.currentTarget.className.indexOf('columnchooser-directional-icons-disabled') != -1) return false;
        const selected = this.getSelectedOptions('SELECTED');
        this.isDataChanged = false;
        this.config.selectedColumns.moveUp(selected[0].index);
    }

    onMoveDown(e: any) {
        if (e.currentTarget.className.indexOf('columnchooser-directional-icons-disabled') != -1) return false;
        const selected = this.getSelectedOptions('SELECTED');
        this.isDataChanged = false;
        this.config.selectedColumns.moveDown(selected[0].index);
    }

    private resetIconsToDefault() {
        this.isUpDownIconDisabled = false;
        this.isLeftIconsDisabled = false;
        this.isRightIconsDisabled = false;
    }

    private getSelectedOptions(type: string) {
        let selectedOptions = [];
        switch (type) {
            case 'AVAILABLE':
                if (this.availablelist.nativeElement.selectedOptions) {
                    selectedOptions = this.availablelist.nativeElement.selectedOptions;
                }
                else {
                    for (let index = 0; index < this.availablelist.nativeElement.options.length; index++) {
                        if (this.availablelist.nativeElement.options[index].selected)
                            selectedOptions.push(this.availablelist.nativeElement.options[index]);
                    }
                }
                break;
            case 'SELECTED':
                if (this.selectedlist.nativeElement.selectedOptions) {
                    selectedOptions = this.selectedlist.nativeElement.selectedOptions;
                }
                else {
                    for (let index = 0; index < this.selectedlist.nativeElement.options.length; index++) {
                        if (this.selectedlist.nativeElement.options[index].selected)
                            selectedOptions.push(this.selectedlist.nativeElement.options[index]);
                    }
                }
                break;
            default:
        }

        return selectedOptions;
    }
}



