import {
  Component, Output, Input, OnInit, ElementRef, Renderer,
  EventEmitter, trigger, animate, transition, state, style, ViewChild
} from '@angular/core';
import { KiewitMenuItem } from '../kiewit-header/kiewit-header';
import { KiewitMenuComponent } from '../kiewit-menu/kiewit-menu.component';
import { KiewitExternalService } from '../kiewit-external.service/kiewit-external.service';
import { KiewitAuthenticationService } from '../kiewit-authentication/kiewit-authentication.service';
import { Adal4User } from "adal-angular4";

@Component({
  selector: 'kiewit-header',
  templateUrl: './kiewit-header.component.html',
  styleUrls: ['./kiewit-header.component.css'],
  animations: [
    trigger('slideDownUp', [
      state('down', style({
        overflow: 'hidden',
        height: 'auto',
        width: 'max-content'
      })),
      state('up', style({
        opacity: '0',
        overflow: 'hidden',
        height: '0px',
        width: 'max-content'
      })),
      transition('down => up', animate('400ms ease-in-out')),
      transition('up => down', animate('400ms ease-in-out'))
    ]),
    trigger('slideLeftRight', [
      state('true', style({
        overflow: 'hidden',
        height: 'auto',
        width: 'max-content'
      })),
      state('false', style({
        opacity: '0',
        backgroundColor: '#000',
        overflow: 'hidden',
        height: '0px',
        width: '0px'
      })),
      transition('true => false', animate('3000ms ease-in-out')),
      transition('false => true', animate('3000ms ease-in-out'))
    ]),
    trigger('userInformationAnimation', [
      state('down', style({
        overflow: 'hidden',
        height: 'auto',
        width: '270px'
      })),
      state('up', style({
        opacity: '0',
        overflow: 'hidden',
        height: '0px',
        width: '270px'
      })),
      transition('down => up', animate('400ms ease-in-out')),
      transition('up => down', animate('400ms ease-in-out'))
    ])
  ],
  providers: [KiewitExternalService, KiewitAuthenticationService]

})
export class KiewitHeaderComponent implements OnInit {

  public applicationHeaderName: string;
  public userInfo: Adal4User;
  public userImage: any;
  public displayUserName: string;
  public displayUserEmail: string;
  isActive: boolean = false;
  @Output()
  buttonSettingsClick: EventEmitter<any> = new EventEmitter();

  @Output()
  subMenuClick: EventEmitter<any> = new EventEmitter();

  @Input()
  isMenuEnabled: boolean;

  @Input()
  menuItems: KiewitMenuItem[];

  settingsClick() {
    this.buttonSettingsClick.emit();
  }

  subMenuOnClick(eventData) {
    this.subMenuClick.emit({ title: eventData.title });
  }

  helpMenuOpen: string;
  showUserInformationPanel: string;

  @ViewChild('kiewitmenu') kiewitmenu: KiewitMenuComponent;

  constructor(public element: ElementRef, private renderer: Renderer, private kiewitExternalService: KiewitExternalService, private kiewitAuthentication: KiewitAuthenticationService) {
    //constructor(public element: ElementRef, private renderer: Renderer, private kiewitExternalService: KiewitExternalService) {

  }

  ngOnInit() {
    this.helpMenuOpen = 'up';
    this.showUserInformationPanel = 'up';
    //this.subMenuOpen = 'true';

    this.kiewitExternalService.getApplicationHeader().subscribe(data => {
      if (data.length > 0) {
        this.applicationHeaderName = data[0].Description;
      }
    });

    this.userInfo = this.kiewitAuthentication.getUser();
    //this.userInfo.username  -- Gives Email address of user
    this.kiewitExternalService.getUserProfileByEmail(this.userInfo.username).subscribe(data => {
      this.userImage = 'data:image/png;base64,' + data[0].Photo;
      this.displayUserEmail = data[0].Email;
      this.displayUserName = data[0].UserName;
    });
  }

  //ngAfterViewInit() {
  //    var la = this.element.nativeElement;//.querySelector('li');
  //    //alert(la);
  //    this.renderer.setElementClass(la, 'kiewit-menu-item', true);
  //    //this.renderer.setStyle(second.nativeElement, 'color', 'blue');
  //}
  /*
  toggleMenu(menuItem: KiewitMenuItem): void {
      //Hide others SubMenuItems
      for (let i = 0; i < this.menuItems.length; i++) {

          if (this.menuItems[i].MenuItemId != menuItem.MenuItemId) {
              this.menuItems[i].IsActive = true;
          }
      }
      //Active only the current MenuItem
      menuItem.IsActive = !menuItem.IsActive
  }*/

  toggleUserProfile(): void {
    this.isActive = !this.isActive;
    setTimeout(() => {
      this.isActive = false;
    }, 5000);
  }
  toggleHelpMenu(): void {
    //this.helpMenuOpen = this.helpMenuOpen === 'up' ? 'down' : 'up';
    this.kiewitmenu.toggleHelpMenu();
  }

  toggleUserInformation(): void {
    this.showUserInformationPanel = this.showUserInformationPanel === 'up' ? 'down' : 'up';
  }

  OpenComponent(subitem): void {

  }
}
